@@ -10,10 +10,14 @@ This file is licensed to you under the license specified in the included file
 #include <stdio.h>
 
 extern int gengetopt_count_line; 
+extern char * gengetopt_input_filename;
 
 void
 yyerror (char *s)
 {
-  fprintf (stderr, "gengetopt: %d: %s\n", gengetopt_count_line, s);
+  fprintf 
+    (stderr, "%s:%d: %s\n", 
+     (gengetopt_input_filename ? gengetopt_input_filename : "gengetopt"), 
+     gengetopt_count_line, s);
 }
 
